@@ -14,7 +14,13 @@ discover_nldi_characteristics <- function(type="all") {
   out <- lapply(tc$type_options[[type]], function(x) {
     o <- query_nldi(paste0(x, "/characteristics"),
                     base_path = "/lookups")
+
+    if(is.null(o)) {
+      return(NULL)
+    }
+
     o$characteristicMetadata$characteristic
+
   })
 
   names(out) <- tc$char_names
@@ -103,11 +109,12 @@ navigate_nldi <- function(nldi_feature, mode = "upstreamMain",
     warning("data source specified as flowline or '' is deprecated")
   }
 
-  dataRetrieval::findNLDI(origin = nldi_feature,
-                          nav = mode,
-                          find = data_source,
-                          distance_km = distance_km,
-                          no_sf = FALSE)
+  tryCatch(dataRetrieval::findNLDI(origin = nldi_feature,
+                                   nav = mode,
+                                   find = data_source,
+                                   distance_km = distance_km,
+                                   no_sf = FALSE),
+           error = function(e) NULL)
 }
 
 #' @title Get NLDI Basin Boundary
@@ -115,8 +122,14 @@ navigate_nldi <- function(nldi_feature, mode = "upstreamMain",
 #' @details Only resolves to the nearest NHDPlus catchment divide. See:
 #' https://waterdata.usgs.gov/blog/nldi-intro/ for more info on the nldi.
 #' @inheritParams navigate_nldi
+#' @param simplify logical should response geometry be simplified for
+#' visualization and performance?
+#' @param split logical should response resolve precisely to the location
+#' of the `nldi_feature`? Setting `TRUE` calls an aditional service and
+#' will be slower and less robust.
 #' @return sf data.frame with result basin boundary
 #' @export
+#' @importFrom sf read_sf
 #' @examples
 #' \donttest{
 #' library(sf)
@@ -124,19 +137,49 @@ navigate_nldi <- function(nldi_feature, mode = "upstreamMain",
 #'
 #' nldi_nwis <- list(featureSource = "nwissite", featureID = "USGS-05428500")
 #'
+#' site <- get_nldi_feature(nldi_nwis)
+#'
 #' basin <- get_nldi_basin(nldi_feature = nldi_nwis)
 #'
-#' basin %>%
-#'  st_geometry() %>%
-#'  plot()
+#' plot(st_geometry(basin))
 #'
 #' basin
+#'
+#' basin2 <- get_nldi_basin(nldi_feature = nldi_nwis,
+#'                          simplify = FALSE, split = TRUE)
+#'
+#' length(st_coordinates(basin))
+#' length(st_coordinates(basin2))
+#'
+#' plot(st_geometry(st_buffer(site, units::set_units(3000, "m"))), border = NA)
+#'
+#' plot(st_geometry(site), add = TRUE)
+#' plot(st_geometry(basin2), add = TRUE)
+#'
+#' plot(st_geometry(basin), border = "red", add = TRUE)
+#'
 #' }
-get_nldi_basin <- function(nldi_feature) {
+get_nldi_basin <- function(nldi_feature, simplify = TRUE, split = FALSE) {
 
-  nldi_feature <- check_nldi_feature(nldi_feature)
+  tryCatch({
+  nldi_feature <- check_nldi_feature(nldi_feature, convert = FALSE)
 
-  dataRetrieval::findNLDI(origin = nldi_feature, find = "basin")$basin
+  o <- query_nldi(
+    paste0(nldi_feature[["featureSource"]], "/",
+           nldi_feature[["featureID"]], "/",
+           "basin?simplify=",
+           ifelse(simplify, "true", "false"), "&",
+           "splitCatchment=",
+           ifelse(split, "true", "false")),
+    parse_json = FALSE)
+
+  if(is.null(o)) return(NULL)
+
+  read_sf(o)
+  }, error = function(e) {
+    warning(e)
+    return(NULL)
+  })
 
 }
 
@@ -153,7 +196,10 @@ get_nldi_basin <- function(nldi_feature) {
 get_nldi_feature <- function(nldi_feature) {
   nldi_feature <- check_nldi_feature(nldi_feature)
 
-  return(dataRetrieval::findNLDI(origin = nldi_feature))
+  out <- tryCatch(dataRetrieval::findNLDI(origin = nldi_feature),
+                  error = function(e) NULL)
+
+  return(out)
 }
 
 #' @title Get Catchment Characteristics
@@ -164,9 +210,11 @@ get_nldi_feature <- function(nldi_feature) {
 #' @return data.frame contianing requested characteristics
 #' @export
 #' @examples
+#' \donttest{
 #' chars <- get_nldi_characteristics(list(featureSource = "nwissite", featureID = "USGS-05429700"))
 #' names(chars)
 #' head(chars$local, 10)
+#' }
 get_nldi_characteristics <- function(nldi_feature, type="local") {
 
   tc <- type_check(type)
@@ -187,6 +235,33 @@ get_nldi_characteristics <- function(nldi_feature, type="local") {
 
 }
 
+#' Get NLDI Index
+#' @description uses the Network Linked Data Index to retrieve and estimated
+#' network location for the given point. If not within a grid cell of a flowline,
+#' will use a raindrop trace service to find the nearest downslope flowline
+#' location.
+#' @param location numeric WGS84 lon/lat pair (X, Y)
+#' @export
+#' @examples
+#' \donttest{
+#' index <- get_nldi_index(c(-89.276, 42.988))
+#'
+#' plot_nhdplus(bbox = sf::st_bbox(sf::st_buffer(index[1,], units::set_units(1000, "m"))))
+#' plot(sf::st_geometry(sf::st_transform(index, 3857)), add = TRUE)
+#' }
+get_nldi_index <- function(location) {
+
+  tryCatch({
+  sf::read_sf(query_nldi(paste0("hydrolocation?coords=POINT(",
+                                location[1],"%20", location[2],")"),
+                         parse_json = FALSE))
+  }, error = function(e) {
+    warning(paste("Something went wrong querying the NLDI.\n", e))
+    NULL
+  })
+
+}
+
 #' @importFrom httr GET
 #' @importFrom jsonlite fromJSON
 #' @noRd
@@ -196,22 +271,27 @@ query_nldi <- function(query, tier = "prod", base_path = "/linked-data", parse_j
   url <- paste(nldi_base_url, query,
                sep = "/")
 
-  req_data <- rawToChar(httr::RETRY("GET", url, times = 3, pause_cap = 60)$content)
+  tryCatch({
+    req_data <- rawToChar(httr::RETRY("GET", url)$content)
 
-  if (nchar(req_data) == 0) {
-    NULL
-  } else {
-    if (parse_json) {
-      tryCatch(jsonlite::fromJSON(req_data, simplifyVector = TRUE),
-               error = function(e) {
-                 message("Something went wrong accessing the NLDI.\n", e)
-               }, warning = function(w) {
-                 message("Something went wrong accessing the NLDI.\n", w)
-               })
+    if (nchar(req_data) == 0) {
+      NULL
     } else {
-      req_data
+      if (parse_json) {
+        tryCatch(jsonlite::fromJSON(req_data, simplifyVector = TRUE),
+                 error = function(e) {
+                   message("Something went wrong accessing the NLDI.\n", e)
+                 }, warning = function(w) {
+                   message("Something went wrong accessing the NLDI.\n", w)
+                 })
+      } else {
+        req_data
+      }
     }
-  }
+  }, error = function(e) {
+    warning("Something went wrong accessing the NLDI.\n", e)
+    NULL
+  })
 }
 
 #' @noRd
